@@ -62,23 +62,24 @@ QUERY__node_credentials_set_public_user = "UPDATE jaaql__credentials_node SET pr
 QUERY__node_credentials_ins = "INSERT INTO jaaql__credentials_node (node, role, db_encrypted_username, db_encrypted_password, precedence) VALUES (:node, :role, :username, :password, coalesce(:precedence, 0))"
 QUERY__node_credentials_del = "UPDATE jaaql__credentials_node SET deleted = current_timestamp WHERE role = :role AND node = :node AND deleted is null"
 QUERY__node_credentials_sel = "SELECT id, node, role, deleted FROM jaaql__credentials_node"
-QUERY__role_connection_sel = "SELECT ad.id as id, ad.db_encrypted_username as username, ad.db_encrypted_password as password, nod.address, nod.port FROM jaaql__credentials_node ad INNER JOIN jaaql__node nod ON nod.name = ad.node WHERE role = (SELECT coalesce(alias, email) FROM jaaql__user WHERE email = :role) AND node = :node AND ad.deleted is null AND nod.deleted is null;"
+QUERY__role_connection_sel = "SELECT ad.id as id, ad.db_encrypted_username as username, ad.db_encrypted_password as password, nod.address, nod.port FROM jaaql__credentials_node ad INNER JOIN jaaql__node nod ON nod.name = ad.node WHERE role = jaaql__fetch_alias_from_id(:user_id) AND node = :node AND ad.deleted is null AND nod.deleted is null;"
 QUERY__node_credentials_count = "SELECT COUNT(*) FROM jaaql__credentials_node"
 QUERY__ins_rendered_document = "INSERT INTO jaaql__rendered_document (encrypted_parameters, encrypted_access_token, document, create_file) VALUES (:parameters, :oauth_token, :name, :create_file) RETURNING document_id"
 QUERY__fetch_rendered_document = "SELECT rd.document_id, able.render_as, rd.filename, rd.create_file, rd.completed, rd.encrypted_access_token as oauth_token FROM jaaql__rendered_document rd INNER JOIN jaaql__renderable_document able ON rd.document = able.name WHERE rd.document_id = :document_id"
 QUERY__purge_rendered_document = "DELETE FROM jaaql__rendered_document WHERE completed is not null and document_id = :document_id RETURNING content"
-QUERY__user_ins = "INSERT INTO jaaql__user (email, mobile, alias, is_public, application, public_credentials) VALUES (lower(:email), :mobile, :alias, :is_public, :application, :public_credentials) RETURNING id"
-QUERY__revoke_user = "UPDATE jaaql__user SET deleted = current_timestamp WHERE email = lower(:username) AND email not in ('jaaql', 'superjaaql') AND deleted is NULL"
+QUERY__user_ins = "INSERT INTO jaaql__user (email, mobile, alias, is_public, application, public_credentials) VALUES (:email, :mobile, :alias, :is_public, :application, :public_credentials) RETURNING id"
+QUERY__postgres_version = "SELECT version() as version;"
+QUERY__revoke_user = "UPDATE jaaql__user SET deleted = current_timestamp WHERE id = :id AND deleted is NULL"
 QUERY__disable_mfa = "UPDATE jaaql__user SET enc_totp_iv = null WHERE id = :user_id"
 QUERY__set_mfa = "UPDATE jaaql__user SET enc_totp_iv = :totp_iv WHERE id = :user_id"
-QUERY__user_id_from_username = "SELECT id FROM jaaql__user WHERE email = lower(:username) AND deleted is null"
+QUERY__user_id_from_username = "SELECT id FROM jaaql__user WHERE email = :username AND deleted is null"
 QUERY__user_totp_upd = "UPDATE jaaql__user SET last_totp = :last_totp WHERE id = :user_id"
 QUERY__user_ip_sel = "SELECT encrypted_address as address, first_use, most_recent_use FROM jaaql__my_ips"
 QUERY__user_ip_count = "SELECT COUNT(*) FROM jaaql__my_ips"
 QUERY__user_ip_ins = "INSERT INTO jaaql__user_ip (the_user, address_hash, encrypted_address) VALUES (:id, :address_hash, :ip_address) ON CONFLICT ON CONSTRAINT jaaql__user_ip_unq DO UPDATE SET most_recent_use = current_timestamp RETURNING most_recent_use <> first_use as existed, id"
 QUERY__user_password_ins = "INSERT INTO jaaql__user_password (the_user, password_hash) VALUES (:the_user, :password_hash)"
-QUERY__fetch_user_latest_password = "SELECT id, email, password_hash, enc_totp_iv as totp_iv, last_totp, is_public FROM jaaql__user_latest_password WHERE email = lower(:username)"
-QUERY__fetch_user_latest_credentials = "SELECT id, email, password_hash, enc_totp_iv as totp_iv, last_totp, is_public, address_hash, ip_id FROM jaaql__user_latest_credentials WHERE email = lower(:username) AND address_hash = :address_hash"
+QUERY__fetch_user_latest_password = "SELECT id, email, password_hash, enc_totp_iv as totp_iv, last_totp, is_public FROM jaaql__user_latest_password WHERE email = :username"
+QUERY__fetch_user_latest_credentials = "SELECT id, email, password_hash, enc_totp_iv as totp_iv, last_totp, is_public, address_hash, ip_id FROM jaaql__user_latest_credentials WHERE email = :username AND address_hash = :address_hash"
 QUERY__sign_up_insert = "INSERT INTO jaaql__sign_up (the_user, email_template, data_lookup_json, invite_code) VALUES (:the_user, :template, :data_lookup_json, :invite_code) RETURNING key_a as invite_key, key_b as invite_poll_key, invite_code as invite_code"
 QUERY__sign_up_count = "SELECT COUNT(*) as count FROM jaaql__sign_up WHERE the_user = :the_user AND (created + interval '24 hour') > current_timestamp"
 QUERY__reset_count = "SELECT COUNT(*) as count FROM jaaql__reset_password WHERE the_user = :the_user AND (created + interval '24 hour') > current_timestamp"
